---
title: "Can the Will Ever Be Regarded as Free?"
date: 2017-06-18T23:49:25Z
tags: ["free will", "determinism"]
topics: ["philosophy"]
image: /img/pinocchio.jpg
draft: false
---

The question at hand, is whether or not the will can ever be regarded as free. Taken at face value, the obvious answer would be, “of course”. Most people, as a matter of fact, regard their will as “free”, most of the time. So, yes, it both can be, and is. Even neuroscientists like Benjamin Libet seem to think so.[^1] But the matter-of-fact interpretation of this question is entirely uninteresting, even as an observation. What we really want to know, is whether this nearly universal intuitive belief is *true* — or, at least, a reasonable belief. More precisely, under what conditions could we judge such a belief, and will those conditions ever be actualized? This is a much more difficult question to answer, and one any wise common person would balk at. As the saying goes, however, fools rush in where angels fear to tread. With that spirit in mind, this paper is an attempt to answer that question by first addressing two more fundamental questions. Firstly, what is this thing we call “the will”? Can it be located in the brain, or at least defined in some tangible way? Secondly, what does it mean to say that this “will” is “free”? Once there is at least some flesh attached to these two concepts, an answer to the broader question will be attempted. However, the ultimate conclusion of this paper will be that there is no conclusion. Try as we might, the question of the freedom of the will remains as unanswerable as ever, and it seems it will remain so for a very long time to come.

### The Problem of The “Will”

What is the “will”? Dan Dennett[^2] urges us to “trade in mystery for mechanisms”, but a close examination of the available science and philosophy on the question suggests that we’ve just traded one mystery for another. Our subjective experience of conscious deliberation and decision-making leads us to believe that the “will” is some sort of unity, within the unity of our larger conscious minds, that takes in external sense data, blends it with emotions and preferences, and outputs intentions to act. Traditional philosophy has long offered elaborate metaphors for this experience, with notions like the “rational faculty” or the capacity for “practical reasoning”[^3]. These metaphors don’t so much explain what the will is, as they simply provide convenient substitute labels for it. Where in the brain is the “rational faculty”, for instance? How, exactly, is it supposed to function? One might say that the answer to this is of course the frontal lobe. But this glib answer, even if it were correct, is far too general. It would be like saying ‘BMWs are made in Germany’. Further, it’s not simply more precision that’s needed. We’re not even sure what *kind* of thing it is we’re talking about. According to Peter Tse[^4], “*will, whether free or not, is not monolithic*”. He describes it as a “*durationally extended process*” – or, more precisely, a “*concatenation of subprocesses*”, made up of the “*operations of different neural circuits*” that activate rapidly in a synchronous “*cascade of steps from abstract plan to concrete action*”. In short, the word “will”, is itself a metaphor. This metaphor is a stand-in for a distinction alluded to initially here, and implicit in Tse’s description of willing. Namely, the distinction between the physical mechanisms of willing, and the subjective experience of a “self” that “wills”. In other words, where in this “durationally extended concatenation of subprocesses”, is the “I” that is doing the desiring, the intending, the planning, and the acting? Is this “I” just an epiphenomenal product of these synchronized cascades of activated neural circuits (a “froth on the waves”, as it were)? If so, how could it have any purchase on the underlying mechanisms that gave rise to it? Jaegwon Kim[^5] clarifies the problem, and gives it some urgency, by pointing out that if we were to claim that such an “I” did have purchase, we’d have to explain how it would not violate the physical principles of closure and overdetermination (in other words, we’d have to explain how we solve the problem of supervenience). In other words, if we want to deny epiphenomenalism, then we have to explain both how the “agent” gets into the machine, and how it is causally antecedent to the neural activity that we can detect. Still, none of these criticisms show conclusively that we are without a will, or that the will is absolutely determined (at least, not entirely). At best, what Kim and others show, is that we are a very long way from a good understanding of what’s really going on in the brain. That being the case, it is difficult to fault thinkers for their metaphors. When the best that neuroscience and philosophy has to offer only affords a metaphorical understanding, then that’s more or less what we must settle upon, in order to have a discussion. On this basis, I take a mixture of Tse and Kane for my understanding of the notion of “will”: a collection of neural sub-processes necessary for the phenomenal experience of deliberative or practical reasoning, *in addition to* the phenomenon itself. What does this mean? How can the “phenomenal experience” be a material part of the willing? One might suspect an attempt to smuggle in an equivocation here. Rather, the intent is to acknowledge looming specter of dualism, and to make an admission to no clear answer to that problem. What’s more, there ought be no expectation that one humble writer is going to solve the riddle of the ages in a short paper. Instead, the point is to cue up one of the conditions for answering the question posed in the title of this essay.

### The Problem of “Freedom”

If the will is merely a “durationally extended concatenation of cascading neural sub-process events”, it is difficult to see why one would need to ask a question like “is it free?” Such a question seems comically nonsensical in this context. It would be like, after hearing a long technical explanation of the functioning of a transistor circuit, one responded with, “yes, but is it orange?” Still, the subjective experience of free choice must be referring to something physical, at least if we want to claim that freedom is a real thing without also committing ourselves to either dualism or mysticism, or both. But as noted earlier, this would further require a conception of self as more than a mere supervenient phenomenon riding on top the wave of electro-chemical activity in the brain.

Tse seems to think that ‘criterial causation’ provides the fix. He argues that neuronal activity is not a simple ‘ballistic’ process, like billiard balls transferring energy between themselves as a matter of causal necessity. Rather, he describes a process of “information transmission”, rather than energy transference. He describes clusters of “epiconnected” neurons acting as “coincidence detectors”, firing not on some quantitative threshold, but on qualitative criteria like coincidences of certain patterns. He argues that these criteria can be altered in the present moment of activity in such a way that future behavior becomes probabilistic. In other words, the resetting of criterial determinates, from moment to moment, renders each subsequent moment unpredictable in an absolute sense (Tse even uses phrases like “will fire or not fire”, to illustrate this). Tse’s theory is difficult for a layman to understand, but even so, it seems to miss the mark as a defense of free will. Firstly, while the idea is fascinating, it is not at all clear how these coincidence detection circuits are “transmitting information”, rather than transferring energy. The distinction is interesting, and Tse is technically correct when he points out that the process is not strictly ballistic. But, even if we take the theory as read, it doesn’t seem to obviate the problem of causal necessity. In fact, it just seems to make the game of billiards fantastically more complicated. Secondly, Tse asserts in several places that his theory provides an explanation for “downward causation” (his term for an agent’s causal efficacy), but his explanation for this was even more opaque than the explanation for coincidence detection. Is he saying that these subprocesses interpose upon and overlap each other somehow? Is he suggesting some kind of feedback loop or call-and-response interaction among the various “epiconnected” groups of neurons? He doesn’t actually say. Whatever this complicated ballet of neuronal behaviors happens to be, it isn’t at all clear why some of them should be regarded as “upward”, while others are regarded as “downward”. What Tse is trying to do with this theory, fundamentally, is to solve the mind-body problem. This is interesting because it suggests that he fears the physicalists may be correct that if there is no “agent”, then there can be no free will. But, his attempt at a theory that makes room for a supervenient agent seems like an attempt to construct the equivalent of a perpetual motion machine in the brain.

In a more global context, what are we really saying when we refer to ourselves as free? Schopenhauer[^6] famously describes “negative” freedom as the absence of fetters or impediments to action. He then makes an analogy from this “physical” freedom to “moral” freedom, arguing that in the same way we are only physically free when we are not shackled by physical restraints, we are only “morally” free when our minds are not shackled by a similar restraint on our capacity to will. For Schopenhauer, that restraint is causal necessity. In other words, for the will to be “free”, it would need to be capable of violating the fundamental laws of physics. It would be easy to caricature Schopenhauer’s notion, by objecting that nobody in his right mind wishes that he could will to turn himself into a dragon, or to both do and not do something simultaneously. But a more serious criticism would be to say that he never specifies anything like what might be considered a ‘null hypothesis’ test, for his claim. When every observable act is invariably traceable backward to a willing event that could only be questioned on the basis of a hypothetical or counterfactual, one is trapped into accepting a conclusion that Schopenhauer, in particular, would have been hoping for: despair.

### The Problem of Finding An Answer

What if, like the notion of the “will”, the notion of “freedom” is also a mere metaphor acting as a verbal tag for a subjective phenomenon that is more complicated and varied than we care to think? What are we really looking for when we go looking for “freedom” in the neuronal neighborhoods of the brain, or in the observable actions of an “agent”? How will we know when we’ve found it? Let’s suppose there is a machine that can map the firings of every neuron, for every decision or action a subject could engage in. Now, suppose this subject were simply speaking his name repeatedly. What if the machine told us that different neurons were firing on every speaking event? Would that mean he was free? What if the machine told us that the exact same neurons were firing every time he spoke. Would that mean he was “not free”? How would this data help us make this determination? What would justify it? Now, more generally, suppose this fellow walks to work every day. Suppose he takes the same route unfailingly. Suppose we keep a record, and note that he as made this same commute for many years. What does this tell us about his metaphysical status? Is he acting freely? How would this information answer that question? Suppose instead, that 10% of the time, he changes his route or takes a taxi. How would this make him any different in a fundamental sense, than his perfectly predictable alternate ego? What these thought experiments suggest, is that the question we’re trying to address is fundamentally unanswerable, because it is unfalsifiable. In short, if looking at the neurons, one cannot tell which are the “effect” of the “agent” and which are the “cause” of the “agent” (or even, which are the “agent”, and which aren’t), then it doesn’t much matter what they’re up to. Likewise, if a ‘free’ agent’s actions are indistinguishable from a ‘determined’ agent’s actions, then once more, one is left without a means for deciding which is which. There doesn’t seem to be a way out of this problem.

### An Attempt At Criteria

It is a truism to say that man is not a machine. In view of the previously stated concern, what could we point to, that would justify an answer in support of this truism? There are three potential criteria that may help us:

1. **The problem of the self**: A means by which we can distinguish agent consciousness from underlying conscious and unconscious mechanisms mingled in the same brain. (i.e., which bits are the ‘self’ or the ‘will’, and which aren’t?)
2. **The problem of supervenience**: A means by which we can distinguish the neural events that are causally antecedent to the agent, from the neural events that are causally descendent from the agent (i.e. which events does the agent ‘control’ and which does he not?)
3. **The problem of necessity**: A means by which we can differentiate causally necessitated actions from ‘free’ actions, assuming that these are oppositional (i.e. which actions *must* happen, versus which actions might have been otherwise?)

It is not at all clear how we would go about testing for these things. And, as mentioned previously, they seem to flirt with dubious notions like dualism and necessity. Though, the third criteria might be easier to tackle than it might seem at first. If we come at it from the direction of the problem of induction, there may be a defense. Still, it seems a mistake to define freedom as something opposed to causality. Why should one’s capacity to make deliberative choices require the distortion or denial of the fundamental laws of nature? Perhaps a better way to phrase the third criteria would be:

- A means by which we can distinguish free actions from unfree actions, given the constraints of nature.

This phrasing seems to allow for theories such as Peter Tse’s criterial causation. But it also raises the specter of unfalsifiability, if we cannot construct a definition of ‘unfree’ that makes any sense. As for the first two criteria, there may eventually be some breakthrough in neuroscience that provides us with a method for differentiating types of neurons and neuronal events to the degree that such things as self-identity and conscious will are “locatable”. But for now, they seem utterly out of reach.

### Conclusion

Given the present state of philosophical thought and neuroscience, it seems clear that there is no clear answer, at the moment, to the question of whether the will can be regarded as free or not. The neuroscience claims of determinism are dubious, and the philosophical claims of freedom are either unfalsifiable, or merely metaphorical. Will the question ever be answerable? This seems doubtful. Some might suggest that if it is answerable, then the answer could only come from neuroscience. But this presupposes the ‘ballistic’ model of neuronal behavior, and a view of causality that presupposes necessity. Both of these presuppositions are questionable. It is highly tempting to believe that the question is answerable, and must be answerable in the affirmative, because freedom underpins so much of our understanding of ourselves, our relationships, and indeed our civilization. In support of this hope, Benjamin Libet gets the last word:

> The phenomenal fact is that most of us feel that we do have free will, at least for some of our actions and within certain limits that may be imposed by our brain’s status and by our environment. The intuitive feelings about the phenomenon of free will form a fundamental basis for views of our human nature, and great care should be taken not to believe allegedly scientific conclusions about them which actually depend upon hidden ad hoc assumptions. A theory that simply interprets the phenomenon of free will as illusory and denies the validity of this phenomenal fact is less attractive than a theory that accepts or accommodates the phenomenal fact.[^7]

[^1]: Walter Sinnott-Armstrong & Lynn Nadel. Conscious Will and Responsibility: A Tribute to Benjamin Libet (Oxford Series in Neuroscience, Law, and Philosophy) (p. 8). Oxford University Press. Kindle Edition.
[^2]: D. Dennett, Freedom Evolves, London, Penguine Books, 2003
[^3]: Robert Kane. The Significance of Free Will (Kindle Locations 314-316). Kindle Edition.
[^4]: Tse, Peter Ulric. The Neural Basis of Free Will: Criterial Causation (MIT Press) (Kindle Location 525). The MIT Press. Kindle Edition. 
[^5]: Kim, Jaegwon. Supervenience and Mind: Selected Philosophical Essays (Cambridge Studies in Philosophy) (Page 3). Cambridge University Press. Kindle Edition.
[^6]: Schopenhauer, Arthur. Essay on the Freedom of the Will (Dover Philosophical Classics) (p. 11). Dover Publications. Kindle Edition. 
[^7]: Walter Sinnott-Armstrong & Lynn Nadel. Conscious Will and Responsibility: A Tribute to Benjamin Libet (Oxford Series in Neuroscience, Law, and Philosophy) (p. 8). Oxford University Press. Kindle Edition. 
